/* common.h
   Shared header file for the shftool package
   Requires Expat (commonly packaged as xmltok-dev)
   Copyright (C) 2003 Linus Walleij

This file is part of the shftool package.

Shftool is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

You should have received a copy of the GNU General Public License
along with Shftool; see the file COPYING.  If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA. 

*/

#ifndef COMMON_INCLUDED
#define COMMON_INCLUDED 1

#ifdef HAVE_SYS_TYPES_H
#include <sys/types.h>
#else
typedef unsigned long long int u_int64_t;
typedef unsigned long int u_int32_t;
typedef unsigned char u_int8_t;
#endif
#if HAVE_STDBOOL_H
# include <stdbool.h>
#else
typedef enum {false = 0, true = 1} bool;
#endif
#include <stdio.h>
#if HAVE_STRING_H
# include <string.h>
#endif
#if HAVE_STDLIB_H
# include <stdlib.h>
#endif
#if HAVE_EXPAT_H
# include <expat.h>
#else
# include <xmlparse.h>
#endif
#define STR_MAXLEN      255
#define BUFFSIZE        8192

// Generic I/O functions
void OutString(char *fmt, ...);
void OutChar(char c);

// Utility functions
char filterHex(char c);
u_int8_t hexToNybble(char c);
void outHexByte(u_int8_t c);
u_int64_t hexStrToULint(const char *str);
void dumpHexArray(u_int8_t *data, u_int64_t len);

// Functions to be implemented by all filters
void startElementHandler(void *data, const XML_Char *el, const XML_Char **attr);
void endElementHandler(void *data, const XML_Char *el);
void textHandler(void *data, const XML_Char *text, int length);
void defaultHandler(void *userData, const XML_Char *s, int length);
void ScanToolOptions(const char **argv, int arg);
void PrintToolHelp(void);

// SHA-1 functions
void initialize_sha1();
void add_byte_to_sha1(u_int8_t c);
u_int8_t *retrieve_sha1(u_int64_t msglen);

#endif
